pub struct EndpointConfig {
pub silence_secs: f32,
pub punct_silence_secs: f32,
pub min_utterance_secs: f32,
}Fields
silence_secs: f32Hard EOU: minimum trailing silence (seconds) after which an utterance is ended (default 2.0).
punct_silence_secs: f32Soft EOU: minimum trailing silence after a terminal punctuation mark (default 0.8).
min_utterance_secs: f32Suppress EOU if the utterance has been running for less than this many seconds (default 0.5).